@@ -1,5 +1,9 @@
 """This is the oldowan.fasta package."""
 
+import os
+
+VERSION = open(os.path.join(os.path.dirname(os.path.realpath(__file__)), 'VERSION')).read().strip()
+
 __all__ = ['fasta', 
            'parse_fasta', 
            'entry2str']
